Task: ConvAI_ChitChat
======================
Description: Human-bot dialogues containing free discussions of randomly chosen paragraphs from SQuAD. Link to dataset: http://convai.io/data/

Tags: #ConvAI_ChitChat, #All, #ChitChat, #decanlp

